@@ -17,11 +17,11 @@ def internet_on() ->bool:
         return False
 
 
-commands = {"Windows": ["cls", "exit", "pip install Morpion --upgrade"], "Linux":["clear", """
+commands = {"Windows": ["cls", "exit", "pip install --upgrade Morpion "], "Linux":["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """, "pip3 install Morpion --upgrade"], "Darwin": ["clear", """
+        """, "pip3 install --upgrade Morpion"], "Darwin": ["clear", """
         osascript -e 'tell application "Terminal" to close first window' && exit
-        """, "pip3 install Morpion --upgrade"] }
+        """, "pip3 install --upgrade Morpion "] }
 sys = platform.system()
 class variables():
     def __init__(self):
@@ -81,11 +81,11 @@ def setGrid(turn, case, value) ->list:
     global grid3
     global grid4
     global grid5
-    grid1 = f"          {cases[1]} | {cases[2]} | {cases[3]}"
+    grid1 = f"           {cases[1]} | {cases[2]} | {cases[3]}"
     grid2 = "           --+---+--"
-    grid3 = f"          {cases[4]} | {cases[5]} | {cases[6]}       tour {turn}"        
+    grid3 = f"           {cases[4]} | {cases[5]} | {cases[6]}       tour {turn}"        
     grid4 = "           --+---+--"
-    grid5 = f"          {cases[7]} | {cases[8]} | {cases[9]}"
+    grid5 = f"           {cases[7]} | {cases[8]} | {cases[9]}"
     return [grid1, grid2, grid3, grid4, grid5]
 
 
